@@ -2,24 +2,27 @@
 about
 """
 
+from typing import List
 from sanic import Blueprint
 from sanic.response import json
-from sanic_openapi import doc
+from sanic_ext import openapi
 
 about_v1 = Blueprint("about_v1", url_prefix="/about")
 
 
 @about_v1.get("/", version=1)
-@doc.tag("General")
-@doc.produces(
+@openapi.tag("General")
+@openapi.response(
+    200,
     {
-        "mode": doc.String(),
-        "versions": doc.List(doc.String()),
+        "application/json": {
+            "mode": str,
+            "versions": List[str],
+        }
     },
     description="OK",
-    content_type="application/json",
 )
-@doc.description("Returns the supported API versions.")
+@openapi.description("Returns the supported API versions.")
 async def about_v1_get(request):  # pylint: disable=unused-argument
     """
     Lists general information about the API.
